@@ -1,7 +1,7 @@
 import json
 from datetime import timedelta
 from inspect import signature
-from typing import Any, Callable, Dict, Optional, Sequence, Union
+from typing import Any, Callable, Dict, Iterable, Optional, Sequence, Union
 
 from starlette import status
 from starlette.background import BackgroundTasks
@@ -15,10 +15,17 @@ from strawberry.asgi.utils import get_graphiql_html
 from strawberry.exceptions import InvalidCustomContext, MissingQueryError
 from strawberry.fastapi.handlers import GraphQLTransportWSHandler, GraphQLWSHandler
 from strawberry.file_uploads.utils import replace_placeholders_with_files
-from strawberry.http import GraphQLHTTPResponse, parse_request_data, process_result
+from strawberry.http import (
+    GraphQLHTTPResponse,
+    parse_query_params,
+    parse_request_data,
+    process_result,
+)
 from strawberry.schema import BaseSchema
+from strawberry.schema.exceptions import InvalidOperationTypeError
 from strawberry.subscriptions import GRAPHQL_TRANSPORT_WS_PROTOCOL, GRAPHQL_WS_PROTOCOL
 from strawberry.types import ExecutionResult
+from strawberry.types.graphql import OperationType
 from strawberry.utils.debug import pretty_print_graphql_operation
 
 
@@ -95,6 +102,7 @@ class GraphQLRouter(APIRouter):
         schema: BaseSchema,
         path: str = "",
         graphiql: bool = True,
+        allow_queries_via_get: bool = True,
         keep_alive: bool = False,
         keep_alive_interval: float = 1,
         debug: bool = False,
@@ -113,6 +121,7 @@ class GraphQLRouter(APIRouter):
         )
         self.schema = schema
         self.graphiql = graphiql
+        self.allow_queries_via_get = allow_queries_via_get
         self.keep_alive = keep_alive
         self.keep_alive_interval = keep_alive_interval
         self.debug = debug
@@ -134,13 +143,29 @@ class GraphQLRouter(APIRouter):
                 },
             },
         )
-        async def get_graphiql() -> Response:
-            if not self.graphiql:
-                return Response(status_code=status.HTTP_404_NOT_FOUND)
-            return self.get_graphiql_response()
+        async def handle_http_get(
+            request: Request,
+            response: Response,
+            context=Depends(self.context_getter),
+            root_value=Depends(self.root_value_getter),
+        ) -> Response:
+            actual_response: Response
+
+            if request.query_params:
+                query_data = parse_query_params(request.query_params._dict)
+                return await self.execute_request(
+                    request=request,
+                    response=response,
+                    data=query_data,
+                    context=context,
+                    root_value=root_value,
+                )
+            elif self.should_render_graphiql(request):
+                return self.get_graphiql_response()
+            return Response(status_code=status.HTTP_400_BAD_REQUEST)
 
         @self.post(path)
-        async def handle_http_query(
+        async def handle_http_post(
             request: Request,
             response: Response,
             context=Depends(self.context_getter),
@@ -175,32 +200,14 @@ class GraphQLRouter(APIRouter):
 
                 return self._merge_responses(response, actual_response)
 
-            try:
-                request_data = parse_request_data(data)
-            except MissingQueryError:
-                actual_response = PlainTextResponse(
-                    "No GraphQL query found in the request",
-                    status_code=status.HTTP_400_BAD_REQUEST,
-                )
-                return self._merge_responses(response, actual_response)
-
-            result = await self.execute(
-                request_data.query,
-                variables=request_data.variables,
+            return await self.execute_request(
+                request=request,
+                response=response,
+                data=data,
                 context=context,
-                operation_name=request_data.operation_name,
                 root_value=root_value,
             )
 
-            response_data = await self.process_result(request, result)
-
-            actual_response = JSONResponse(
-                response_data,
-                status_code=status.HTTP_200_OK,
-            )
-
-            return self._merge_responses(response, actual_response)
-
         @self.websocket(path)
         async def websocket_endpoint(
             websocket: WebSocket,
@@ -246,6 +253,14 @@ class GraphQLRouter(APIRouter):
             default=None,
         )
 
+    def should_render_graphiql(self, request: Request) -> bool:
+        if not self.graphiql:
+            return False
+        return any(
+            supported_header in request.headers.get("accept", "")
+            for supported_header in ("text/html", "*/*")
+        )
+
     def get_graphiql_response(self) -> HTMLResponse:
         html = get_graphiql_html()
         return HTMLResponse(html)
@@ -259,7 +274,13 @@ class GraphQLRouter(APIRouter):
         return actual_response
 
     async def execute(
-        self, query, variables=None, context=None, operation_name=None, root_value=None
+        self,
+        query: str,
+        variables: Optional[Dict[str, Any]] = None,
+        context: Any = None,
+        operation_name: Optional[str] = None,
+        root_value: Any = None,
+        allowed_operation_types: Optional[Iterable[OperationType]] = None,
     ):
         if self.debug:
             pretty_print_graphql_operation(operation_name, query, variables)
@@ -270,9 +291,52 @@ class GraphQLRouter(APIRouter):
             variable_values=variables,
             operation_name=operation_name,
             context_value=context,
+            allowed_operation_types=allowed_operation_types,
         )
 
     async def process_result(
         self, request: Request, result: ExecutionResult
     ) -> GraphQLHTTPResponse:
         return process_result(result)
+
+    async def execute_request(
+        self, request: Request, response: Response, data: dict, context, root_value
+    ) -> Response:
+        try:
+            request_data = parse_request_data(data)
+        except MissingQueryError:
+            missing_query_response = PlainTextResponse(
+                "No GraphQL query found in the request",
+                status_code=status.HTTP_400_BAD_REQUEST,
+            )
+            return self._merge_responses(response, missing_query_response)
+
+        method = request.method
+        allowed_operation_types = OperationType.from_http(method)
+
+        if not self.allow_queries_via_get and method == "GET":
+            allowed_operation_types = allowed_operation_types - {OperationType.QUERY}
+
+        try:
+            result = await self.execute(
+                request_data.query,
+                variables=request_data.variables,
+                context=context,
+                operation_name=request_data.operation_name,
+                root_value=root_value,
+                allowed_operation_types=allowed_operation_types,
+            )
+        except InvalidOperationTypeError as e:
+            return PlainTextResponse(
+                e.as_http_error_reason(method),
+                status_code=status.HTTP_400_BAD_REQUEST,
+            )
+
+        response_data = await self.process_result(request, result)
+
+        actual_response: JSONResponse = JSONResponse(
+            response_data,
+            status_code=status.HTTP_200_OK,
+        )
+
+        return self._merge_responses(response, actual_response)
